@@ -376,7 +376,6 @@ impl<T: Config> P2PSession<T> {
 
         // handle all events locally
         for (event, handles, addr) in events.drain(..) {
-            assert_eq!(handles.len(), 1);
             self.handle_event(event, handles, addr);
         }
 
@@ -408,7 +407,9 @@ impl<T: Config> P2PSession<T> {
                     self.disconnect_player_at_frame(player_handle, last_frame);
                     return Ok(());
                 }
-                Err(GGRSError::PlayerDisconnected)
+                Err(GGRSError::InvalidRequest {
+                    info: "Player already disconnected.".to_owned(),
+                })
             }
             // disconnecting spectators is simpler
             Some(PlayerType::Spectator(_)) => {
@@ -606,15 +607,11 @@ impl<T: Config> P2PSession<T> {
         self.sync_layer.reset_prediction();
 
         // step forward to the previous current state, but with updated inputs
-        for _ in 0..count {
+        for i in 0..count {
             let inputs = self
                 .sync_layer
                 .synchronized_inputs(&self.local_connect_status);
 
-            // advance the frame
-            self.sync_layer.advance_frame();
-            requests.push(GGRSRequest::AdvanceFrame { inputs });
-
             // decide wether to request a state save
             if self.sparse_saving {
                 // with sparse saving, we only save exactly the min_confirmed frame
@@ -622,9 +619,15 @@ impl<T: Config> P2PSession<T> {
                     requests.push(self.sync_layer.save_current_state());
                 }
             } else {
-                // without sparse saving, we save every state except the very first one
-                requests.push(self.sync_layer.save_current_state());
+                // without sparse saving, we save every state except the very first (just loaded that))
+                if i > 0 {
+                    requests.push(self.sync_layer.save_current_state());
+                }
             }
+
+            // advance the frame
+            self.sync_layer.advance_frame();
+            requests.push(GGRSRequest::AdvanceFrame { inputs });
         }
         // after all this, we should have arrived at the same frame where we started
         assert_eq!(self.sync_layer.current_frame(), current_frame);
