@@ -1,43 +1,35 @@
-use ggrs::{P2PSession, P2PSpectatorSession, PlayerType, SessionState};
-use std::net::{IpAddr, Ipv4Addr, SocketAddr};
-
-use serial_test::serial;
-
 mod stubs;
 
-#[test]
-#[serial]
-fn test_create_session() {
-    let host_addr = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 7777);
-    assert!(P2PSpectatorSession::new(1, stubs::INPUT_SIZE, 9999, host_addr).is_ok());
-}
+use ggrs::{GGRSError, PlayerType, SessionBuilder, SessionState, UdpNonBlockingSocket};
+use serial_test::serial;
+use std::net::{IpAddr, Ipv4Addr, SocketAddr};
+use stubs::StubConfig;
 
 #[test]
 #[serial]
 fn test_start_session() {
     let host_addr = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 7777);
-    let mut spec_sess = P2PSpectatorSession::new(1, stubs::INPUT_SIZE, 9999, host_addr).unwrap();
-    assert!(spec_sess.start_session().is_ok());
+    let socket = UdpNonBlockingSocket::bind_to_port(9999).unwrap();
+    let spec_sess = SessionBuilder::<StubConfig>::new().start_spectator_session(host_addr, socket);
     assert!(spec_sess.current_state() == SessionState::Synchronizing);
 }
 
 #[test]
 #[serial]
-fn test_synchronize_with_host() {
+fn test_synchronize_with_host() -> Result<(), GGRSError> {
     let host_addr = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 7777);
     let spec_addr = SocketAddr::new(IpAddr::V4(Ipv4Addr::new(127, 0, 0, 1)), 8888);
 
-    let mut host_sess =
-        P2PSession::<Vec<u8>>::new(1, stubs::INPUT_SIZE, stubs::MAX_PRED_FRAMES, 7777).unwrap();
-    let mut spec_sess = P2PSpectatorSession::new(1, stubs::INPUT_SIZE, 8888, host_addr).unwrap();
+    let socket1 = UdpNonBlockingSocket::bind_to_port(7777).unwrap();
+    let mut host_sess = SessionBuilder::<StubConfig>::new()
+        .with_num_players(1)
+        .add_player(PlayerType::Local, 0)?
+        .add_player(PlayerType::Spectator(spec_addr), 2)?
+        .start_p2p_session(socket1)?;
 
-    host_sess.add_player(PlayerType::Local, 0).unwrap();
-    host_sess
-        .add_player(PlayerType::Spectator(spec_addr), 2)
-        .unwrap();
-
-    host_sess.start_session().unwrap();
-    spec_sess.start_session().unwrap();
+    let socket2 = UdpNonBlockingSocket::bind_to_port(8888).unwrap();
+    let mut spec_sess =
+        SessionBuilder::<StubConfig>::new().start_spectator_session(host_addr, socket2);
 
     assert_eq!(spec_sess.current_state(), SessionState::Synchronizing);
     assert_eq!(host_sess.current_state(), SessionState::Synchronizing);
@@ -49,4 +41,6 @@ fn test_synchronize_with_host() {
 
     assert_eq!(spec_sess.current_state(), SessionState::Running);
     assert_eq!(host_sess.current_state(), SessionState::Running);
+
+    Ok(())
 }
